summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmisosurfaceedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmisosurfaceedit.h')
-rw-r--r--kpovmodeler/pmisosurfaceedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmisosurfaceedit.h b/kpovmodeler/pmisosurfaceedit.h
index 09798c0d..c0a1dda4 100644
--- a/kpovmodeler/pmisosurfaceedit.h
+++ b/kpovmodeler/pmisosurfaceedit.h
@@ -41,12 +41,13 @@ class TQLineEdit;
class PMIsoSurfaceEdit : public PMSolidObjectEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMIsoSurfaceEdit with parent and name
*/
- PMIsoSurfaceEdit( TQWidget* parent, const char* name = 0 );
+ PMIsoSurfaceEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -41,12 +41,13 @@ class TQLineEdit;
public:
/**
- * Creates a PMIsoSurfaceEdit with parent and name
+ * Creates a PMIsoSurfaceEdit with tqparent and name
*/